@@ -12,7 +12,7 @@ use MooX::Types::MooseLike::Base qw(CodeRef Str);
 use Try::Tiny;
 use namespace::autoclean;
 
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 
 # plural_ref e.g. ru
 # The key is the plural form 0, 1 or 2.
@@ -620,13 +620,13 @@ __END__
 
 Locale::Utils::Autotranslator - Base class to translate automaticly
 
-$Id: Autotranslator.pm 614 2015-08-17 10:28:48Z steffenw $
+$Id: Autotranslator.pm 641 2017-02-24 13:14:23Z steffenw $
 
 $HeadURL: $
 
 =head1 VERSION
 
-1.001
+1.002
 
 =head1 SYNOPSIS
 
@@ -685,6 +685,10 @@ Base class to translate automaticly.
 
 =head1 SUBROUTINES/METHODS
 
+=head2 method new
+
+see SYNOPSIS
+
 =head2 method developer_language
 
 Get back the language of all msgid's. The default is 'en';
@@ -794,7 +798,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2014 - 2015,
+Copyright (c) 2014 - 2017,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
