@@ -11,7 +11,7 @@ use MooX::StrictConstructor;
 use URI;
 use namespace::autoclean;
 
-our $VERSION = '1.000';
+our $VERSION = '1.002';
 
 extends qw(
     Locale::Utils::Autotranslator
@@ -71,7 +71,7 @@ $HeadURL: $
 
 =head1 VERSION
 
-1.000
+1.002
 
 =head1 SYNOPSIS
 
@@ -105,6 +105,10 @@ Interface for translated.net
 
 =head1 SUBROUTINES/METHODS
 
+=head2 method new
+
+see SYNOPSIS
+
 =head2 method translate_text
 
     $translated = $object->translate_text($untranslated);
@@ -160,7 +164,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2014 - 2015,
+Copyright (c) 2014 - 2017,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
